
#include <BLEDevice.h>
#include <BLEUtils.h>
#include <BLEServer.h>
#include <HardwareSerial.h>

HardwareSerial Serial2(1);
bool light = 0;

#define SERVICE_UUID        "4fafc201-1fb5-459e-8fcc-c5c9c331914b"
#define CHARACTERISTIC_UUID "beb5483e-36e1-4688-b7f5-ea07361b26a8"
#define RXp2 20
#define TXp2 21 //defining receiving and transmitting pins for UART communication.

class MyCallbacks: public BLECharacteristicCallbacks {
  void onWrite(BLECharacteristic *pCharacteristic) { //whenever a message is received from bluetoooth
    std::string value = pCharacteristic->getValue(); //set the message received to a string variable

    if (value.length() > 0) { //if the message is at least 1 character long
      if (value[0] - 48 == 0) //and the first character is 0
        light = 0;          // set the light to off
      else if (value[0] - 48 == 1) //otherwise if the first character is 1
        light = 1;          // set the light to on
    }
  }
};

void setup() {
  Serial2.begin(9600, SERIAL_8N1, RXp2, TXp2); // open a serial monitor to listen to the arduino
  pinMode(2,OUTPUT);  // set the pin with the led to output

  BLEDevice::init("DanDevBoard"); // name the bluetooth device so I can find it easily
  BLEServer *pServer = BLEDevice::createServer(); // create a bluetooth server named pServer

  BLEService *pService = pServer->createService(SERVICE_UUID); // create a bluetooth service called pService

  BLECharacteristic *pCharacteristic = pService->createCharacteristic( //add a charactaristic that says that
                                         CHARACTERISTIC_UUID,          //the device can read and write
                                         BLECharacteristic::PROPERTY_READ |
                                         BLECharacteristic::PROPERTY_WRITE
                                       );

  pCharacteristic->setCallbacks(new MyCallbacks());
  //sets the callback operation to an instance of the MyCallbacks class

  pCharacteristic->setValue("Hello World");
  pService->start();

  BLEAdvertising *pAdvertising = pServer->getAdvertising();
  pAdvertising->start(); //starts broadcasting it's existance to the universe
}

void loop() {
  // put your main code here, to run repeatedly:
  switch(Serial2.parseInt()) { //reads the serial monitor and grabs the first integer it can find
  case 1: //if the monitor had integer 1
    light = 1; //set light to on
    break;
  case 2: //if the monitor had integer 2
    light = 0; //set light to off
    break;
  default: //if it was some other number
    break; //do nothing
  }
  if(light){ //if the light should be on
    digitalWrite(2,HIGH); //turn it on
  }else{  // otherwise turn it off
    digitalWrite(2,LOW);
  }
}
